@@ -5,7 +5,7 @@
 import copy
 from pathlib import Path
 
-import simplejson as json
+import  json
 
 from mootdx.consts import EX_HOSTS
 from mootdx.consts import GP_HOSTS
@@ -14,16 +14,16 @@ from mootdx.logger import logger
 from mootdx.server import bestip
 from mootdx.utils import get_config_path
 
-__all__ = ['set', 'get', 'copy', 'update', 'settings']
+__all__ = ["set", "get", "copy", "update", "settings"]
 
 settings = {
-    'SERVER': {'HQ': HQ_HOSTS, 'EX': EX_HOSTS, 'GP': GP_HOSTS},
-    'BESTIP': {'HQ': '', 'EX': '', 'GP': ''},
-    'TDXDIR': 'C:/new_tdx',
+    "SERVER": {"HQ": HQ_HOSTS, "EX": EX_HOSTS, "GP": GP_HOSTS},
+    "BESTIP": {"HQ": "", "EX": "", "GP": ""},
+    "TDXDIR": "C:/new_tdx",
 }
 
 BASE = Path(__file__).parent.parent
-CONF = get_config_path('config.json')
+CONF = get_config_path("config.json")
 
 
 def setup():
@@ -35,10 +35,10 @@ def setup():
     global settings
 
     try:
-        options = json.load(open(CONF, 'r', encoding='utf-8'))
+        options = json.load(open(CONF, "r", encoding="utf-8"))
         settings.update(options)
     except (json.JSONDecodeError, FileNotFoundError):
-        logger.warning(f'未找到配置文件 {CONF}, 正在生成配置文件.')
+        logger.warning(f"未找到配置文件 {CONF}, 正在生成配置文件.")
         bestip() and setup()
 
     return True if settings else False
@@ -77,7 +77,7 @@ def get(key, default=None):
     :return:
     """
 
-    key = key.split('.')
+    key = key.split(".")
     cfg = settings.get(key[0])
 
     if len(key) > 1:
