@@ -5,15 +5,16 @@ import socket
 import time
 from functools import partial
 
+from tdxpy.constants import hq_hosts
+
 from mootdx.consts import CONFIG
 from mootdx.consts import EX_HOSTS
 from mootdx.consts import GP_HOSTS
-from mootdx.consts import HQ_HOSTS
 from mootdx.logger import logger
 from mootdx.utils import get_config_path
 
 hosts = {
-    "HQ": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in HQ_HOSTS],
+    "HQ": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in hq_hosts + GP_HOSTS],
     "EX": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in EX_HOSTS],
     "GP": [{"addr": hs[1], "port": hs[2], "time": 0, "site": hs[0]} for hs in GP_HOSTS],
 }
@@ -33,7 +34,7 @@ def callback(res, key):
     if result.get("time"):
         results[key].append(result)
 
-    logger.debug("callback: {}", res.result())
+    # logger.debug(f"callback: {res.result()}")
 
 
 def connect(proxy: dict) -> dict:
@@ -115,7 +116,7 @@ def server(index=None, limit=5, console=False, sync=True):
         t.align["Time"] = "r"
         t.padding_width = 1
 
-        for host in server[: int(limit)]:
+        for host in server:
             t.add_row(
                 [
                     host["site"],
@@ -125,7 +126,7 @@ def server(index=None, limit=5, console=False, sync=True):
                 ]
             )
 
-        logger.debug(t)
+        logger.debug("\n" + str(t))
 
     return [(item["addr"], item["port"]) for item in server]
 
